@@ -165,15 +165,15 @@ class LogicalVolumeSerializer(serializers.ModelSerializer):
 
 
 class StorageConfigurationDriveSerializer(serializers.ModelSerializer):
-    linux_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
+    drive = NestedDriveSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
         model = StorageConfigurationDrive
         fields = (
             "id",
-            "device",
-            "linux_volume",
+            "drive",
+            "virtual_machine",
             "created",
             "last_updated",
             "custom_fields",
