@@ -12,9 +12,6 @@ class DriveTable(NetBoxTable):
     """Table for displaying Drives objects."""
 
     pk = ToggleColumn()
-    storage_configuration = tables.Column(
-        linkify=True
-    )
     identifier = tables.Column(
         linkify=True
     )
@@ -32,11 +29,9 @@ class DriveTable(NetBoxTable):
             "size",
             "cluster",
             "identifier",
-            "storage_configuration",
             "description",
         )
         default_columns = (
-            "storage_configuration",
             "identifier",
             "size",
             "cluster",
