@@ -11,10 +11,22 @@ class VMTemplateContent(PluginTemplateExtension):
     def left_page(self):
         obj = self.context.get("object")
 
-        storage_configuration = StorageConfigurationDrive.objects.filter(virtual_machine=obj)
-        partitions = []
-        for sc in storage_configuration:
-            partitions += list(Partition.objects.filter(drive=sc.drive))
+        drives_id = StorageConfigurationDrive.objects.values('drive').filter(virtual_machine=obj)
+        print(f"Drives id: {drives_id}")
+        drives = []
+        for drive_id in drives_id:
+            drives.append(Drive.objects.get(pk=drive_id))
+
+        print(f"drives: {drives}")
+        partition_dict = {}
+        for drive_id in drives_id:
+            print(f"Drive ID: {drive_id['drive']}")
+            drive = Drive.objects.get(pk=drive_id['drive'])
+
+            if Partition.objects.filter(drive=drive).count() == 0:
+                partition_dict[drive] = None
+            else:
+                partition_dict[drive] = list(Partition.objects.filter(drive=drive))
 
         platform = obj.platform
         if platform is not None:
@@ -22,7 +34,7 @@ class VMTemplateContent(PluginTemplateExtension):
                 return self.render(
                     "netbox_storage/inc/vm_windows_box.html",
                     extra_context={
-                        "partitions": partitions,
+                        "partition_dict": partition_dict,
                     },
                 )
             elif platform.name.lower().__contains__('linux'):
