@@ -2,7 +2,7 @@ from netbox.views import generic
 
 from netbox_storage.forms.template import LVMTemplateForm, DriveTemplateForm, \
     PartitionTemplateForm
-from netbox_storage.models import TemplateConfigurationDrive, Partition, LogicalVolume, MountedVolume
+from netbox_storage.models import TemplateConfigurationDrive, Partition, LogicalVolume, MountedVolume, LinuxDevice
 
 
 class LVMAddTemplateView(generic.ObjectEditView):
@@ -17,5 +17,5 @@ class AddTemplateDriveView(generic.ObjectEditView):
 
 
 class AddTemplatePartitionView(generic.ObjectEditView):
-    queryset = Partition.objects.all()
+    queryset = LinuxDevice.objects.all()
     form = PartitionTemplateForm
